@@ -27,7 +27,7 @@ After the imports, this code runs identically on Python 3 and 2::
     from itertools import filterfalse
     from test import support
 
-    # Backported Py3-like bytes object
+    # Backported Py3 bytes object
     b = bytes(b'ABCD')
     assert list(b) == [65, 66, 67, 68]
     assert repr(b) == "b'ABCD'"
@@ -35,6 +35,19 @@ After the imports, this code runs identically on Python 3 and 2::
     # b + u'EFGH'
     # bytes(b',').join([u'Fred', u'Bill'])
 
+    # Backported Py3 str object
+    s = str(u'ABCD')
+    assert s != b'ABCD'
+    assert isinstance(s.encode('utf-8'), bytes)
+    assert isinstance(b.decode('utf-8'), str)
+    assert repr(s) == 'ABCD'      # consistent repr with Py3 (no u prefix)
+    # These raise TypeErrors:
+    # b'B' in s
+    # s.find(b'A')
+
+    # Extra arguments for the open() function
+    f = open('japanese.txt', encoding='utf-8', errors='replace')
+    
     # New iterable range object with slicing support
     for i in range(10**15)[:10]:
         pass
@@ -52,10 +65,6 @@ After the imports, this code runs identically on Python 3 and 2::
     # These raise NameErrors:
     # apply(), cmp(), coerce(), reduce(), xrange(), etc.
     
-    # This identity is restored. This is normally valid on Py3 and Py2,
-    # but 'from __future__ import unicode_literals' breaks it on Py2:
-    assert isinstance('happy', str)
-    
     # The round() function behaves as it does in Python 3, using
     # "Banker's Rounding" to the nearest even last digit:
     assert round(0.1250, 2) == 0.12
@@ -156,15 +165,14 @@ Explicit imports
 If you prefer explicit imports, the explicit equivalent of the ``from
 future.builtins import *`` line above is::
     
-    from future.builtins.iterators import zip, map, filter
-    from future.builtins.misc import ascii, oct, hex, chr, input
-    from future.builtins.backports import bytes, range, super, round
-    from future.builtins.disabled import (apply, cmp, coerce,
-            execfile, file, long, raw_input, reduce, reload, unicode,
+    from future.builtins.iterators import (filter, map, zip)
+    from future.builtins.misc import (ascii, chr, hex, input, int, oct, open)
+    from future.builtins.backports import (bytes, range, round, str, super)
+    from future.builtins.disabled import (apply, cmp, coerce, execfile,
+            file, long, raw_input, reduce, reload, unicode,
             xrange, StandardError)
-    from future.builtins.str_is_unicode import str
 
-But please note that the API is still evolving rapidly.
+But please note that the internal API is still evolving.
 
 See the docstrings for each of these modules for more info::
 
@@ -174,27 +182,36 @@ See the docstrings for each of these modules for more info::
 
 
 Automatic conversion
-====================
+--------------------
 An experimental script called ``futurize`` is included to aid in making
 either Python 2 code or Python 3 code compatible with both platforms
-using the ``future`` module. See
-https://github.com/edschofield/python-future#automatic-conversion.
+using the ``future`` module. See `<http://python-future.org/automatic_conversion.html>`_.
+
+
+Documentation
+-------------
+
+See http://python-future.org
 
 
 Credits
-=======
+-------
+
 :Author:  Ed Schofield
 :Sponsor: Python Charmers Pty Ltd, Australia, and Python Charmers Pte
           Ltd, Singapore. http://pythoncharmers.com
-:Others:  - ``future`` incorporates the ``six`` module by Benjamin
-            Peterson.
+:Others:  - The backported ``super()`` and ``range()`` functions are
+            derived from Ryan Kelly's ``magicsuper`` module and Dan
+            Crosta's ``xrange`` module.
           - The ``futurize`` script uses ``lib2to3``, ``lib3to2``, and
             parts of Armin Ronacher's ``python-modernize`` code.
-          - The backported ``super()`` and ``range()`` functions are
-            derived from Ryan Kelly's ``magicsuper`` module and Dan Crosta's
-            ``xrange`` module.
           - The ``python_2_unicode_compatible`` decorator is from
-            ``django.utils.encoding``.
+            Django. The ``implements_iterator`` and ``with_metaclass``
+            decorators are from Jinja2.
+          - ``future`` incorporates the ``six`` module by Benjamin
+            Peterson as ``future.utils.six``.
+          - Documentation is generated using ``sphinx`` using an
+            adaptation of Armin Ronacher's stylesheets from Jinja2.
 
 
 Licensing
@@ -202,36 +219,15 @@ Licensing
 Copyright 2013 Python Charmers Pty Ltd, Australia.
 The software is distributed under an MIT licence. See LICENSE.txt.
 
-
-FAQ
-===
-See https://github.com/edschofield/python-future#faq.
-
 """
-# pylint: disable=W0622,W0401
 
-from future import utils
-from future.builtins import *
-
-if not utils.PY3:
-    # Only shadow builtins on Py2; no new names
-    __all__ = ['filter', 'map', 'zip', 
-               'ascii', 'oct', 'hex', 'chr', 'int',
-               'apply', 'cmp', 'coerce', 'execfile', 'file', 'long',
-               'raw_input', 'reduce', 'reload', 'unicode', 'xrange',
-               'StandardError',
-               'bytes', 'round', 'input', 'range', 'super',
-               'str']
-
-else:
-    # No namespace pollution on Py3
-    __all__ = []
+# No namespace pollution
+__all__ = []
 
 __ver_major__ = 0
-__ver_minor__ = 5
-__ver_patch__ = 2
+__ver_minor__ = 6
+__ver_patch__ = 0
 __ver_sub__ = ''
 __version__ = "%d.%d.%d%s" % (__ver_major__, __ver_minor__,
                               __ver_patch__, __ver_sub__)
 
-
