@@ -3,14 +3,14 @@ For the ``future`` package.
 
 Adds this import line:
 
-    from future import *
+    from future.builtins import *
 
 after any other imports (in an initial block of them).
 """
 
 from lib2to3.fixer_base import BaseFix
-from lib2to3.fixer_util import touch_import
 from lib2to3.pygram import python_symbols as syms
+from libfuturize.fixer_util import touch_import_top
 
        
 class FixFutureBuiltins(BaseFix):
@@ -21,5 +21,5 @@ class FixFutureBuiltins(BaseFix):
         return False
     
     def transform(self, node, results):
-        touch_import(u'future', u'*', node)
+        touch_import_top(u'future.builtins', u'*', node)
 
