@@ -3,7 +3,7 @@ Fixer for division: from __future__ import division if needed
 """
 
 from lib2to3 import fixer_base
-from lib3to2.fixer_util import token, future_import
+from libfuturize.fixer_util import token, future_import
 
 def match_division(node):
     u"""
